<?php
/**
 * Architectonic Pro: Color Patterns
 *
 * @package WordPress
 * @subpackage Architectonic Pro
 * @since 1.0
 */

/**
 * Generate the CSS for the current custom color scheme.
 */
function architectonic_pro_custom_colors_css() {
  	$options= architectonic_pro_get_theme_options();

	$color_value = $options['colorscheme_hue'];
	
	$css = '
	.main-navigation ul#primary-menu li.current-menu-item > a:before,
	#about-us .section-title:after,
	.btn-primary,
	.backtotop,
	.blog-posts .post-categories,
	#secondary .jetpack_subscription_widget input[type="submit"]:hover, 
	#secondary .jetpack_subscription_widget input[type="submit"]:focus,
	.author-name:after,
	.reply a:hover, 
	.reply a:focus,
	#respond input[type="submit"],
	#main-slider.main-slider-classic .slick-dots li:before,
	#client-testimonial .entry-header:after,
	.popup-video:hover, 
	.popup-video:focus { 
		background-color: ' . esc_attr($color_value) . '; 
	}';

	$css .= '
	.main-navigation ul#primary-menu li.current-menu-item > a, 
	.main-navigation ul#primary-menu li:hover > a, 
	.main-navigation ul#primary-menu li:focus > a,
	.main-navigation a:hover, 
	.main-navigation a:focus, 
	.main-navigation ul.nav-menu > li > a:hover, 
	.main-navigation ul.nav-menu > li > a:focus,
	.custom-meta-title,
	#main-slider .entry-title a:hover, 
	#main-slider .entry-title a:focus,
	#top-navigation .widget_contact_info ul li a:hover, 
	#top-navigation .widget_contact_info ul li a:focus,
	#latest-projects .entry-title a:hover, 
	#latest-projects .entry-title a:focus,
	#our-services .entry-title a:hover, 
	#our-services .entry-title a:focus,
	.posts-wrapper  .entry-title a:hover, 
	.posts-wrapper  .entry-title a:focus,
	#client-testimonial .entry-title a:hover, 
	#client-testimonial .entry-title a:focus,
	.footer-widgets-area a:hover, 
	.footer-widgets-area a:focus,
	.pagination .page-numbers.current, 
	.pagination .page-numbers:hover, 
	.pagination .page-numbers:focus,
	.widget_popular_post h3 a:hover, 
	.widget_popular_post h3 a:focus, 
	.widget_popular_post a:hover time, 
	.widget_popular_post a:focus time, 
	.widget_recent_post h3 a:hover, 
	.widget_recent_post h3 a:focus, 
	.widget_recent_post a:hover time, 
	.widget_recent_post a:focus time,
	.post-categories a,
	.single-post-wrapper span.tags-link a:hover, 
	.single-post-wrapper span.tags-link a:focus,
	.post-navigation a:hover, 
	.posts-navigation a:hover, 
	.post-navigation a:focus, 
	.posts-navigation a:focus,
	.comment-meta .url:hover, 
	.comment-meta .url:focus, 
	.comment-metadata a, 
	.comment-metadata a time,
	a,
	.icon-container a:hover .fa,
	.icon-container a:focus .fa,
	.site-info a,
	#secondary .widget ul li:hover:before, 
	#colophon .widget ul li:hover:before,
	#secondary ul li a:hover,
	.single-post-wrapper span.tags-links a:hover, 
	.single-post-wrapper span.tags-links a:focus,
	.single-post-wrapper .entry-meta span.posted-on a:hover .date,
	.single-post-wrapper .entry-meta span.posted-on a:focus .date,
	.single-post-wrapper span.posted-on a:hover,
	.single-post-wrapper span.posted-on a:focus,
	.widget_popular_post h3 a:hover, 
	.widget_popular_post h3 a:focus, 
	.widget_popular_post a:hover time, 
	.widget_popular_post a:focus time, 
	.widget_latest_post h3 a:hover, 
	.widget_latest_post h3 a:focus, 
	.widget_latest_post a:hover time, 
	.widget_latest_post a:focus time,
	#secondary .architectonic_pro_contact_info ul li.phone:hover:before,
	#colophon .architectonic_pro_contact_info ul li.phone:hover:before {
		color: ' . esc_attr($color_value) . '; 
	}';

	$css .= '
	.main-navigation ul#primary-menu li:hover > svg, 
	.main-navigation ul#primary-menu li:focus > svg, 
	.main-navigation li.menu-item-has-children:hover > a > svg, 
	.main-navigation li.menu-item-has-children > a:hover > svg, 
	.main-navigation li.menu-item-has-children > a:focus > svg,
	.main-navigation ul.nav-menu > li > a.search:hover svg.icon-search, 
	.main-navigation ul.nav-menu > li > a.search:focus svg.icon-search, 
	.main-navigation li.search-menu a:hover svg, 
	.main-navigation li.search-menu a:focus svg, 
	.main-navigation li.search-menu a.search-active svg,
	.icon-container a:hover svg, 
	.icon-container a:focus svg,
	.navigation.posts-navigation a:hover svg, 
	.navigation.post-navigation a:hover svg,
	.widget_search form.search-form button.search-submit:hover svg, 
	.widget_search form.search-form button.search-submit:focus svg, 
	.no-results .search-submit:hover svg, 
	.error-404 .search-submit:hover svg { 
		fill: ' . esc_attr($color_value) . '; 
	}';

	$css .= '
	.single-post-wrapper span.tags-link a:hover, 
	.single-post-wrapper span.tags-link a:focus,
	.reply a:hover, 
	.reply a:focus,
	.single-post-wrapper span.tags-links a:hover, 
	.single-post-wrapper span.tags-links a:focus { 
		border-color: ' . esc_attr($color_value) . '; 
	}';

	$css .= '
	.slick-active .slider-nav .slide-title,
	.more-link { 
		border-bottom-color: ' . esc_attr($color_value) . '; 
	}';

	$css .= '
	@keyframes preloader {
	    0% {height:5px;transform:translateY(0px);background: ' . esc_attr($color_value) . ';}
	    25% {height:30px;transform:translateY(15px);background: ' . esc_attr($color_value) . ';}
	    50% {height:5px;transform:translateY(0px);background: ' . esc_attr($color_value) . ';}
	    100% {height:5px;transform:translateY(0px);background: ' . esc_attr($color_value) . ';}
	}';

	/**
	 * Filters Architectonic Pro custom colors CSS.
	 *
	 * @since Architectonic Pro 1.0.0
	 *
	 * @param string $css        Base theme colors CSS.
	 */
	return apply_filters( 'architectonic_pro_custom_colors_css', $css );
}
