<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Architectonic Pro
 * @since Architectonic Pro 1.0.0
 */
if ( ! function_exists( 'architectonic_pro_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since Architectonic Pro 1.0.0
    */
    function architectonic_pro_add_blog_section() {
    	$options = architectonic_pro_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'architectonic_pro_section_status', true, 'blog_section_enable' );

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'architectonic_pro_filter_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        architectonic_pro_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'architectonic_pro_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Architectonic Pro 1.0.0
    * @param array $input blog section details.
    */
    function architectonic_pro_get_blog_section_details( $input ) {
        $options = architectonic_pro_get_theme_options();

        // Content type.
        $blog_content_type  = $options['blog_content_type'];
        $blog_count = ! empty( $options['blog_count'] ) ? $options['blog_count'] : 4;
        
        $content = array();
        switch ( $blog_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = architectonic_pro_trim_content( 15 );
                $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'architectonic_pro_filter_blog_section_details', 'architectonic_pro_get_blog_section_details' );


if ( ! function_exists( 'architectonic_pro_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Architectonic Pro 1.0.0
   *
   */
   function architectonic_pro_render_blog_section( $content_details = array() ) {
        $options = architectonic_pro_get_theme_options();
        $readmore = ! empty( $content['read_more_text'] ) ? $content['read_more_text'] : esc_html__( 'Read More', 'architectonic-pro' );
        $column = ! empty( $options['blog_column'] ) ? $options['blog_column'] : 'col-4';
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="latest-posts" class="relative">
            <div class="wrapper">
                <?php if ( ! empty( $options['blog_title'] ) || ! empty( $options['blog_subtitle'] ) ) : ?>
                    <div class="section-header">
                        <div class="wrapper">
                            <?php if ( ! empty( $options['blog_subtitle'] ) ) : ?>
                                <span class="custom-meta-title"><?php echo esc_html( $options['blog_subtitle'] ); ?></span>
                            <?php endif; 

                            if ( ! empty( $options['blog_title'] ) ) : ?>
                                <h2 class="section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>
                            <?php endif; ?>
                        </div>
                    </div><!-- .section-header -->
                <?php endif; ?>

                <!-- supports col-2,col-3,col-4 -->
                <div class="section-content">
                    <div class="wrapper">
                        <div class="posts-wrapper <?php echo esc_attr( $column ); ?>">
                            <?php foreach ( $content_details as $content ) : ?>
                                <article class="hentry">
                                    <div class="entry-meta">
                                        <?php architectonic_pro_posted_on( $content['id'] ); ?>   
                                    </div><!-- .entry-meta -->

                                    <?php if ( ! empty( $content['image'] ) ) : ?>
                                        <div class="featured-image">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>"><img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php echo esc_attr( $content['title'] ); ?>"></a>
                                        </div><!-- .featured-image -->
                                    <?php endif; ?>

                                    <div class="entry-container">
                                        <header class="entry-header">
                                            <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                        </header>

                                        <div class="entry-content">
                                            <?php echo esc_html( $content['excerpt'] ); ?>
                                        </div><!-- .entry-content -->

                                        <div class="read-more">
                                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="more-link"><?php echo esc_html( $readmore ); ?></a>
                                        </div><!-- .read-more -->
                                    </div><!-- .entry-container -->
                                </article>
                            <?php endforeach; ?>
                        </div><!-- .posts-wrapper -->

                        <?php if ( ! empty( $options['blog_btn_title'] ) && ! empty( $options['blog_btn_url'] ) ) : ?>
                            <div class="view-all">
                                <a href="<?php echo esc_url( $options['blog_btn_url'] ); ?>" class="btn btn-primary white"><?php echo esc_html( $options['blog_btn_title'] ); ?></a>
                            </div><!-- .read-more -->
                        <?php endif; ?>
                    </div><!-- .wrapper -->
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #latest-posts -->

    <?php }
endif;